"""This package contains a collection of programs to read and write Broadcast Wave files. Several proprietary file formats that include additional metadata chunks are supported. See the docstring of the wavefile module for details on the supported formats.
"""
__all__ = ["wavefile", "recorders"]
